# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/schema.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/schema.proto',
  package='schema',
  syntax='proto3',
  serialized_options=_b('Z+github.com/opencord/voltha-protos/go/schema'),
  serialized_pb=_b('\n\x1avoltha_protos/schema.proto\x12\x06schema\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"A\n\tProtoFile\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\r\n\x05proto\x18\x02 \x01(\t\x12\x12\n\ndescriptor\x18\x03 \x01(\x0c\"U\n\x07Schemas\x12!\n\x06protos\x18\x01 \x03(\x0b\x32\x11.schema.ProtoFile\x12\x14\n\x0cswagger_from\x18\x02 \x01(\t\x12\x11\n\tyang_from\x18\x03 \x01(\t2V\n\rSchemaService\x12\x45\n\tGetSchema\x12\x16.google.protobuf.Empty\x1a\x0f.schema.Schemas\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/schemaB-Z+github.com/opencord/voltha-protos/go/schemab\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_PROTOFILE = _descriptor.Descriptor(
  name='ProtoFile',
  full_name='schema.ProtoFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='schema.ProtoFile.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proto', full_name='schema.ProtoFile.proto', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptor', full_name='schema.ProtoFile.descriptor', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=162,
)


_SCHEMAS = _descriptor.Descriptor(
  name='Schemas',
  full_name='schema.Schemas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protos', full_name='schema.Schemas.protos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swagger_from', full_name='schema.Schemas.swagger_from', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yang_from', full_name='schema.Schemas.yang_from', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=249,
)

_SCHEMAS.fields_by_name['protos'].message_type = _PROTOFILE
DESCRIPTOR.message_types_by_name['ProtoFile'] = _PROTOFILE
DESCRIPTOR.message_types_by_name['Schemas'] = _SCHEMAS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoFile = _reflection.GeneratedProtocolMessageType('ProtoFile', (_message.Message,), dict(
  DESCRIPTOR = _PROTOFILE,
  __module__ = 'voltha_protos.schema_pb2'
  # @@protoc_insertion_point(class_scope:schema.ProtoFile)
  ))
_sym_db.RegisterMessage(ProtoFile)

Schemas = _reflection.GeneratedProtocolMessageType('Schemas', (_message.Message,), dict(
  DESCRIPTOR = _SCHEMAS,
  __module__ = 'voltha_protos.schema_pb2'
  # @@protoc_insertion_point(class_scope:schema.Schemas)
  ))
_sym_db.RegisterMessage(Schemas)


DESCRIPTOR._options = None

_SCHEMASERVICE = _descriptor.ServiceDescriptor(
  name='SchemaService',
  full_name='schema.SchemaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=251,
  serialized_end=337,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSchema',
    full_name='schema.SchemaService.GetSchema',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SCHEMAS,
    serialized_options=_b('\202\323\344\223\002\t\022\007/schema'),
  ),
])
_sym_db.RegisterServiceDescriptor(_SCHEMASERVICE)

DESCRIPTOR.services_by_name['SchemaService'] = _SCHEMASERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import yang_options_pb2 as voltha__protos_dot_yang__options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/common.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('Z+github.com/opencord/voltha-protos/go/common'),
  serialized_pb=_b('\n\x1avoltha_protos/common.proto\x12\x06\x63ommon\x1a voltha_protos/yang_options.proto\"\x10\n\x02ID\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x03IDs\x12\x19\n\x05items\x18\x01 \x03(\x0b\x32\n.common.ID\"c\n\x08LogLevel\"P\n\x08LogLevel\x12\t\n\x05\x44\x45\x42UG\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05:\x05\xf0\xf6\xcd\x1d\x00\"\x81\x01\n\nAdminState\"l\n\nAdminState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0ePREPROVISIONED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03\x12\x15\n\x11\x44OWNLOADING_IMAGE\x10\x04\x12\x0b\n\x07\x44\x45LETED\x10\x05:\x05\xf0\xf6\xcd\x1d\x00\"s\n\nOperStatus\"^\n\nOperStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nDISCOVERED\x10\x01\x12\x0e\n\nACTIVATING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05:\x05\xf0\xf6\xcd\x1d\x00\"T\n\rConnectStatus\"<\n\rConnectStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bUNREACHABLE\x10\x01\x12\r\n\tREACHABLE\x10\x02:\x05\xf0\xf6\xcd\x1d\x00\"\xc8\x01\n\rOperationResp\x12\x37\n\x04\x63ode\x18\x01 \x01(\x0e\x32).common.OperationResp.OperationReturnCode\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\"^\n\x13OperationReturnCode\x12\x15\n\x11OPERATION_SUCCESS\x10\x00\x12\x15\n\x11OPERATION_FAILURE\x10\x01\x12\x19\n\x15OPERATION_UNSUPPORTED\x10\x02:\x05\xf0\xf6\xcd\x1d\x00*\x1c\n\x0cTestModeKeys\x12\x0c\n\x08\x61pi_test\x10\x00\x42-Z+github.com/opencord/voltha-protos/go/commonb\x06proto3')
  ,
  dependencies=[voltha__protos_dot_yang__options__pb2.DESCRIPTOR,])

_TESTMODEKEYS = _descriptor.EnumDescriptor(
  name='TestModeKeys',
  full_name='common.TestModeKeys',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='api_test', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=763,
  serialized_end=791,
)
_sym_db.RegisterEnumDescriptor(_TESTMODEKEYS)

TestModeKeys = enum_type_wrapper.EnumTypeWrapper(_TESTMODEKEYS)
api_test = 0


_LOGLEVEL_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='common.LogLevel.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=136,
  serialized_end=216,
)
_sym_db.RegisterEnumDescriptor(_LOGLEVEL_LOGLEVEL)

_ADMINSTATE_ADMINSTATE = _descriptor.EnumDescriptor(
  name='AdminState',
  full_name='common.AdminState.AdminState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREPROVISIONED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOADING_IMAGE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=240,
  serialized_end=348,
)
_sym_db.RegisterEnumDescriptor(_ADMINSTATE_ADMINSTATE)

_OPERSTATUS_OPERSTATUS = _descriptor.EnumDescriptor(
  name='OperStatus',
  full_name='common.OperStatus.OperStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCOVERED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVATING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=371,
  serialized_end=465,
)
_sym_db.RegisterEnumDescriptor(_OPERSTATUS_OPERSTATUS)

_CONNECTSTATUS_CONNECTSTATUS = _descriptor.EnumDescriptor(
  name='ConnectStatus',
  full_name='common.ConnectStatus.ConnectStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNREACHABLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REACHABLE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=491,
  serialized_end=551,
)
_sym_db.RegisterEnumDescriptor(_CONNECTSTATUS_CONNECTSTATUS)

_OPERATIONRESP_OPERATIONRETURNCODE = _descriptor.EnumDescriptor(
  name='OperationReturnCode',
  full_name='common.OperationResp.OperationReturnCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERATION_SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_UNSUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=660,
  serialized_end=754,
)
_sym_db.RegisterEnumDescriptor(_OPERATIONRESP_OPERATIONRETURNCODE)


_ID = _descriptor.Descriptor(
  name='ID',
  full_name='common.ID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='common.ID.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=88,
)


_IDS = _descriptor.Descriptor(
  name='IDs',
  full_name='common.IDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='common.IDs.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=122,
)


_LOGLEVEL = _descriptor.Descriptor(
  name='LogLevel',
  full_name='common.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGLEVEL_LOGLEVEL,
  ],
  serialized_options=_b('\360\366\315\035\000'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=223,
)


_ADMINSTATE = _descriptor.Descriptor(
  name='AdminState',
  full_name='common.AdminState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADMINSTATE_ADMINSTATE,
  ],
  serialized_options=_b('\360\366\315\035\000'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=355,
)


_OPERSTATUS = _descriptor.Descriptor(
  name='OperStatus',
  full_name='common.OperStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPERSTATUS_OPERSTATUS,
  ],
  serialized_options=_b('\360\366\315\035\000'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=472,
)


_CONNECTSTATUS = _descriptor.Descriptor(
  name='ConnectStatus',
  full_name='common.ConnectStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTSTATUS_CONNECTSTATUS,
  ],
  serialized_options=_b('\360\366\315\035\000'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=558,
)


_OPERATIONRESP = _descriptor.Descriptor(
  name='OperationResp',
  full_name='common.OperationResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='common.OperationResp.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_info', full_name='common.OperationResp.additional_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPERATIONRESP_OPERATIONRETURNCODE,
  ],
  serialized_options=_b('\360\366\315\035\000'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=761,
)

_IDS.fields_by_name['items'].message_type = _ID
_LOGLEVEL_LOGLEVEL.containing_type = _LOGLEVEL
_ADMINSTATE_ADMINSTATE.containing_type = _ADMINSTATE
_OPERSTATUS_OPERSTATUS.containing_type = _OPERSTATUS
_CONNECTSTATUS_CONNECTSTATUS.containing_type = _CONNECTSTATUS
_OPERATIONRESP.fields_by_name['code'].enum_type = _OPERATIONRESP_OPERATIONRETURNCODE
_OPERATIONRESP_OPERATIONRETURNCODE.containing_type = _OPERATIONRESP
DESCRIPTOR.message_types_by_name['ID'] = _ID
DESCRIPTOR.message_types_by_name['IDs'] = _IDS
DESCRIPTOR.message_types_by_name['LogLevel'] = _LOGLEVEL
DESCRIPTOR.message_types_by_name['AdminState'] = _ADMINSTATE
DESCRIPTOR.message_types_by_name['OperStatus'] = _OPERSTATUS
DESCRIPTOR.message_types_by_name['ConnectStatus'] = _CONNECTSTATUS
DESCRIPTOR.message_types_by_name['OperationResp'] = _OPERATIONRESP
DESCRIPTOR.enum_types_by_name['TestModeKeys'] = _TESTMODEKEYS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ID = _reflection.GeneratedProtocolMessageType('ID', (_message.Message,), dict(
  DESCRIPTOR = _ID,
  __module__ = 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.ID)
  ))
_sym_db.RegisterMessage(ID)

IDs = _reflection.GeneratedProtocolMessageType('IDs', (_message.Message,), dict(
  DESCRIPTOR = _IDS,
  __module__ = 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.IDs)
  ))
_sym_db.RegisterMessage(IDs)

LogLevel = _reflection.GeneratedProtocolMessageType('LogLevel', (_message.Message,), dict(
  DESCRIPTOR = _LOGLEVEL,
  __module__ = 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.LogLevel)
  ))
_sym_db.RegisterMessage(LogLevel)

AdminState = _reflection.GeneratedProtocolMessageType('AdminState', (_message.Message,), dict(
  DESCRIPTOR = _ADMINSTATE,
  __module__ = 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.AdminState)
  ))
_sym_db.RegisterMessage(AdminState)

OperStatus = _reflection.GeneratedProtocolMessageType('OperStatus', (_message.Message,), dict(
  DESCRIPTOR = _OPERSTATUS,
  __module__ = 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.OperStatus)
  ))
_sym_db.RegisterMessage(OperStatus)

ConnectStatus = _reflection.GeneratedProtocolMessageType('ConnectStatus', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTSTATUS,
  __module__ = 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.ConnectStatus)
  ))
_sym_db.RegisterMessage(ConnectStatus)

OperationResp = _reflection.GeneratedProtocolMessageType('OperationResp', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONRESP,
  __module__ = 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.OperationResp)
  ))
_sym_db.RegisterMessage(OperationResp)


DESCRIPTOR._options = None
_LOGLEVEL._options = None
_ADMINSTATE._options = None
_OPERSTATUS._options = None
_CONNECTSTATUS._options = None
_OPERATIONRESP._options = None
# @@protoc_insertion_point(module_scope)
